@@ -18,6 +18,8 @@ from .config import Config
 from .defaults import CONFIG_PATH, FOLDER_PATH
 from .slide import reverse_video_path
 
+WINDOW_NAME = "Manim Slides"
+
 
 @unique
 class State(IntEnum):
@@ -174,10 +176,20 @@ class Presentation:
 
 
 class Display:
-    def __init__(self, presentations, config, start_paused=False, fullscreen=False):
+    def __init__(
+        self,
+        presentations,
+        config,
+        start_paused=False,
+        fullscreen=False,
+        skip_all=False,
+    ):
         self.presentations = presentations
         self.start_paused = start_paused
         self.config = config
+        self.skip_all = skip_all
+        self.fullscreen = fullscreen
+        self.is_windows = platform.system() == "Windows"
 
         self.state = State.PLAYING
         self.lastframe = None
@@ -186,27 +198,27 @@ class Display:
         self.lag = 0
         self.last_time = now()
 
-        if platform.system() == "Windows":
+        if self.is_windows:
             user32 = ctypes.windll.user32
             self.screen_width, self.screen_height = user32.GetSystemMetrics(
                 0
             ), user32.GetSystemMetrics(1)
 
-        if fullscreen:
-            cv2.namedWindow("Video", cv2.WND_PROP_FULLSCREEN)
+        if self.fullscreen:
+            cv2.namedWindow(WINDOW_NAME, cv2.WND_PROP_FULLSCREEN)
             cv2.setWindowProperty(
-                "Video", cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_FULLSCREEN
+                WINDOW_NAME, cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_FULLSCREEN
             )
 
     def resize_frame_to_screen(self, frame: np.ndarray):
-        frame_height, frame_width = frame.shape
+        frame_height, frame_width = frame.shape[:2]
 
         scale_height = self.screen_height / frame_height
         scale_width = self.screen_width / frame_width
 
         scale = min(scale_height, scale_width)
 
-        return cv2.resize(frame, (int(scale * frame_height, scale * frame_width)))
+        return cv2.resize(frame, (int(scale * frame_height), int(scale * frame_width)))
 
     @property
     def current_presentation(self):
@@ -237,10 +249,10 @@ class Display:
 
         frame = self.lastframe
 
-        if platform.system() == "Windows":
+        if self.is_windows and self.fullscreen:
             frame = self.resize_frame_to_screen(frame)
 
-        cv2.imshow("Video", frame)
+        cv2.imshow(WINDOW_NAME, frame)
 
     def show_info(self):
         info = np.zeros((130, 420), np.uint8)
@@ -276,7 +288,7 @@ class Display:
             *font_args,
         )
 
-        cv2.imshow("Info", info)
+        cv2.imshow(f"{WINDOW_NAME}: Info", info)
 
     def handle_key(self):
         sleep_time = math.ceil(1000 / self.current_presentation.fps)
@@ -293,7 +305,9 @@ class Display:
         ):
             self.current_presentation.next()
             self.state = State.PLAYING
-        elif self.state == State.PLAYING and self.config.CONTINUE.match(key):
+        elif (
+            self.state == State.PLAYING and self.config.CONTINUE.match(key)
+        ) or self.skip_all:
             self.current_presentation.next()
         elif self.config.BACK.match(key):
             if self.current_presentation.current_slide_i == 0:
@@ -356,8 +370,15 @@ def _list_scenes(folder):
     is_flag=True,
     help="Show the next animation first frame as last frame (hack).",
 )
+@click.option(
+    "--skip-all",
+    is_flag=True,
+    help="Skip all slides, useful the test if slides are working.",
+)
 @click.help_option("-h", "--help")
-def present(scenes, config_path, folder, start_paused, fullscreen, last_frame_next):
+def present(
+    scenes, config_path, folder, start_paused, fullscreen, last_frame_next, skip_all
+):
     """Present the different scenes."""
 
     if len(scenes) == 0:
@@ -411,6 +432,10 @@ def present(scenes, config_path, folder, start_paused, fullscreen, last_frame_ne
         config = Config()
 
     display = Display(
-        presentations, config=config, start_paused=start_paused, fullscreen=fullscreen
+        presentations,
+        config=config,
+        start_paused=start_paused,
+        fullscreen=fullscreen,
+        skip_all=skip_all,
     )
     display.run()
